@@ -1,3 +1,4 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
 use utf8;
@@ -6,18 +7,58 @@ package Git::Wrapper::Plus::Ref;
 BEGIN {
   $Git::Wrapper::Plus::Ref::AUTHORITY = 'cpan:KENTNL';
 }
-{
-  $Git::Wrapper::Plus::Ref::VERSION = '0.002000';
-}
-
+$Git::Wrapper::Plus::Ref::VERSION = '0.003000';
 # ABSTRACT: An Abstract REF node
 
 
-use Moo;
 
 
-has name => is => ro =>, required => 1;
-has git  => is => ro =>, required => 1;
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+use Moo qw( has );
+
+
+
+
+
+
+
+
+
+
+
+has 'name' => ( is => ro =>, required => 1 );
+has 'git'  => ( is => ro =>, required => 1 );
+
+
+
+
+
+
+
+
+
+
+
 
 
 sub refname {
@@ -26,6 +67,11 @@ sub refname {
 }
 
 
+
+
+
+
+
 sub sha1 {
   my ($self)    = @_;
   my ($refname) = $self->refname;
@@ -52,7 +98,7 @@ Git::Wrapper::Plus::Ref - An Abstract REF node
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 SYNOPSIS
 
@@ -108,7 +154,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
