@@ -1,3 +1,4 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
 use utf8;
@@ -6,28 +7,59 @@ package Git::Wrapper::Plus::Ref::Tag;
 BEGIN {
   $Git::Wrapper::Plus::Ref::Tag::AUTHORITY = 'cpan:KENTNL';
 }
-{
-  $Git::Wrapper::Plus::Ref::Tag::VERSION = '0.002000';
-}
-
+$Git::Wrapper::Plus::Ref::Tag::VERSION = '0.003000';
 # ABSTRACT: A single tag object
 
 
-use Moo;
+
+
+
+
+
+
+
+
+
+
+
+use Moo qw( extends );
 extends 'Git::Wrapper::Plus::Ref';
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 sub new_from_Ref {
-  my ( $class, $object ) = @_;
-  if ( not $object->can('name') ) {
+  my ( $class, $source_object ) = @_;
+  if ( not $source_object->can('name') ) {
     require Carp;
-    return Carp::croak("Object $object does not respond to ->name, cannot Ref -> Tag");
+    return Carp::croak("Object $source_object does not respond to ->name, cannot Ref -> Tag");
   }
-  my $name = $object->name;
+  my $name = $source_object->name;
+  ## no critic ( Compatibility::PerlMinimumVersionAndWhy )
   if ( $name =~ qr{\Arefs/tags/(.+\z)}msx ) {
     return $class->new(
-      git  => $object->git,
+      git  => $source_object->git,
       name => $1,
     );
   }
@@ -36,18 +68,33 @@ sub new_from_Ref {
 }
 
 
+
+
+
+
+
+
+
+
+
 sub refname {
   my ($self) = @_;
   return 'refs/tags/' . $self->name;
 }
 
 
+
+
+
 sub verify {
   my ( $self, ) = @_;
   return $self->git->tag( '-v', $self->name );
 }
 
 
+
+
+
 ## no critic (ProhibitBuiltinHomonyms)
 
 sub delete {
@@ -70,7 +117,7 @@ Git::Wrapper::Plus::Ref::Tag - A single tag object
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 SYNOPSIS
 
@@ -123,7 +170,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
